const { Group, Field } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Heading = require('../Heading');
let BasicText = require('../BasicText');
let Columns = require('../Columns');
let Colors = require('../Colors');
let Image = require('./Image');
let Icon = require('./Icon');
let Button = require('./Button');

module.exports = class extends GlobalGroup {

	constructor() { 
		super();
		this.name("blurbs", "Blurbs")
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#standardFields());
		})
	}

	// --- Fields

	#standardFields() {
		return [
			
			Field
				.choice()
				.choices([
					['none', 'None'],
					['icon', 'Icons'],
					['image', 'Large Images'],
					['animation', 'Animated numbers']
				])
				.name('media_type', 'Visual aid above blurb text')
				.default('none'),
            
			new Group()
                .name('items', 'Blurbs')
                .children([
                    Field
                        .boolean()
						.name('visible', 'Enable this Blurb')
						.set('display', 'toggle')
                        .inlineHelpText("Check to show blurb.")
                        .default(true),
                    new Group()
                        .name('text', 'Text')
                        .children([
                            new Heading()
                                .inlineHelpText('This is the Heading for the Blurb')
                                .default('I\'m the Blurb Heading'),
                            new BasicText()
                                .name('description', 'Description')
                                .default('Quis aute iure reprehenderit in voluptate velit esse. Quid securi etiam tamquam eu fugiat nulla pariatur. Excepteur sint obcaecat cupiditat non proident culpa.')
                        ]),
                    new Icon()
                        .visibleIf('content.media_type', 'icon'),
                    new Image()
						.visibleIf('content.media_type', 'image')
						.showRatio()
						.showSize(),
                    new Group()
						.name('animated_number', 'Animated numbers')
						.visibleIf('content.media_type', 'animation')
                        .children([
                            Field.number()
                                .name('number', 'Animated number')
                                .inlineHelpText('This number will be animated')
                                .default(2),
                            Field.text()
                                .name('prefix', 'Prefix')
                                .inlineHelpText('If you want to add a prefix to the number, e.g. $, €'),
                            Field.text()
                                .name('suffix', 'Suffix')
                                .inlineHelpText('If you want to add a suffix to the number, e.g. %, +, k'),                         
                            Field.text()
                                .name('subtitle', 'Sub title')
                                .inlineHelpText('Shown under the number, e.g. Customers')                        
						]),
					new Button()
						.name('buttons', 'Buttons')
						.repeat({
							"min": 0,
							"max": 2,
							"sorting_label_field": 'content.ites.buttons.button_label',
							"default": 0
						})
                ]).repeat({
                    'min' : 0,
                    'max' : null,
                    'sorting_label_field' : 'content.items.text.heading',
                    'default' : 3
            	}),

            new Group()
                .name('layout', 'Blurbs Style')
                .children([
                    new Columns(),
                    Field
                        .boolean()
                        .name('add_blurb_bg', 'Add a background to the blurbs')
						.set('display', 'toggle')
                        .inlineHelpText('Adds a background to each blurb for a card look')
                        .default(false),        
                    new Colors()
                        .name('blurb_bg', 'Background color')
                        .visibleIf('content.layout.add_blurb_bg', true),
					Field
						.boolean()
						.name('add_border', 'Add border around blurbs')
						.set('display', 'toggle')
						.default(false),			
					new Colors()
						.name('border_color', 'Border color')
						.default('primary')
						.visibleIf('content.layout.add_border', true),
                    Field
                        .boolean()
                        .name('equal_height', 'Make blurbs equal height')
						.set('display', 'toggle')
                        .inlineHelpText('Best used when border or background is added. Looks best when text content is of similar length')
                        .default(false),
                    Field
                        .boolean()
                        .name('add_hover', 'Add hover effect')
						.set('display', 'toggle')
                        .inlineHelpText('Scaling hover effect is applied to all blurbs')
                        .default(false),
                    Field
                        .boolean()
                        .name('add_shadow', 'Add shadow')
						.set('display', 'toggle')
                        .default(false)
                ])

	    ]
	}

}