const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Button = require('./Button');

module.exports = class extends GlobalGroup {

	constructor() {
		super();
		this.name('buttons', 'Buttons')
		this.buttonGroupId = randomId()
		this.showButtonsId = randomId()
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#standardFields());
			(this._showEnable ? this.prependChildren(this.#enableField()) : null);
		})
	}

	// --- Show/Hide

	_showEnable = true
	showEnable(val = true) {
		this._showEnable = !!val
		return this._build()
	}

	_applyToButtons = false
	applyToButtons(fn) { 
		this._applyToButtons = typeof fn =='function' ? fn : null
		return this._build()
	}
	
	// --- Settings

	_minButtons = 0
	minButtons(val) {
		this._minButtons = parseInt(val) || 0
		return this._build()
	}
	
	_maxButtons = 4
	maxButtons(val) {
		this._maxButtons = parseInt(val) || 4
		return this._build()
	}

	// --- Fields

	#standardFields() {
		return new Button()
			.name('buttons', 'Buttons')
			.id(this.buttonGroupId)
			.repeat({
				"min": this._minButtons,
				"max": this._maxButtons,
				"sorting_label_field": this.buttonGroupId + '.button_label',
				"default": null
			})
			.applyIf(this._showEnable, field => field.visibleIf(this.showButtonsId, true))
			.applyIf(!!this._applyToButtons, field => this._applyToButtons(field) )
	}

	#enableField() {
		return Field
			.boolean()
			.name('show', 'Enable Buttons')
			.id(this.showButtonsId)
			.set('display', 'toggle')
			.default(true)
	}

}