const { Field, config } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let CssId = require('../CssId');
let CssClass = require('../CssClass');

module.exports = class extends GlobalGroup {

	constructor() {
		super();
		this.name('settings', 'Settings')
		this._build()
		return this
	}

	_build() {
		let showClass = this._showCssClass != null ? !!this._showCssClass : !!config('includeAdvancedCss');
		return this._buildChildrenArray(() => { 
			(showClass ? this.appendChildren(this.#cssClassField()) : null);
			(this._showCssId ? this.appendChildren(this.#cssIdField()) : null);
			(this._showDisableBlock ? this.appendChildren(this.#disableBlockField()) : null);
		})
	}
	
	// --- Show/Hide

	_showCssClass = null
	showCssClass(val = true) {
		this._showCssClass = val == null ? null : !!val
		return this._build()
	}

	_showCssId = true
	showCssId(val = true) {
		this._showCssId = !!val
		return this._build()
	}

	_showDisableBlock = true
	showDisableBlock(val = true) {
		this._showDisableBlock = !!val
		return this._build()
	}

	// --- Fields

	#cssClassField() {
		return new CssClass()
			.name('section_class', 'Section Class')
			.inlineHelpText("Enter a CSS class for additional styling")
	}
	
	#cssIdField() {
		return new CssId()
			.name('section_id', 'Section ID')
			.inlineHelpText("Enter an ID that will be used to scroll to this section from anchors.")
			.helpText("Applies to outer section")
	}

	#disableBlockField() {
		return Field
			.boolean()
			.name('disable_block', 'Disable Block')
			.helpText('Hide the module but keep the setting saved.')
			.set("display","toggle")
			.default(false)
	}

}