const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Columns = require('../Columns');
let FlexDirection = require('../FlexDirection');

module.exports = class extends GlobalGroup { 
	
	constructor() {
		super()
		this.name('social', 'Social Links')
		this.repeaterId = randomId()
		this.labelsId = randomId()
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#standardFields());
			this.appendChildren(this.#layoutGroup());
		})
	}

	// --- Settings

	_applyToSocialLinks = false
	applyToSocialLinks(fn) { 
		this._applyToSocialLinks = typeof fn =='function' ? fn : null
		return this._build()
	}

	_minSocialLinks = 0
	minSocialLinks(val) {
		this._minSocialLinks = parseInt(val) || 0
		return this._build()
	}
	
	_maxSocialLinks = 10
	maxSocialLinks(val) {
		this._maxSocialLinks = parseInt(val) || 10
		return this._build()
	}

	#standardFields() {
		return new GlobalGroup()
			.name('links', 'Links')
			.id(this.repeaterId)
			.applyIf(!!this._applyToSocialLinks, field => this._applyToSocialLinks(field))
			.children([
				Field
					.choice()
					.name('network', 'Network')
					.inlineHelpText('Select Social Network')
					.choices([
						['facebook', 'Facebook'],
						['instagram', 'Instagram'],
						['spotify', 'Spotify'],
						['tiktok', 'TikTok'],
						['soundcloud', 'SoundCloud'],
						['snapchat', 'Snapchat'],
						['youtube', 'YouTube'],
						['twitter', 'Twitter'],
						['mixcloud', 'Mixcloud'],
						['googleplus', 'Google Plus'],
						['linkedin', 'LinkedIn'],
						['whatsapp', 'WhatsApp'],
						['vimeo', 'Vimeo'],
						['hashtag', 'Hashtag (Icon)'],
						['grid', 'Grid (Icon for Blog)'],
						['rss', 'Rss (Icon for Blog)'],
					]),
				Field
					.boolean()
					.name('visible', 'Enable this item')
					.set('display', 'toggle')
					.default(true),
				Field
					.text()
					.name('custom_label', 'Custom Label')
					.inlineHelpText('Override Network Name.'),
				Field
					.url()
					.set('supported_types', ["EXTERNAL", "EMAIL_ADDRESS"])
					.name('link', 'Link')
					.set('default',{ href: '#' })

			])
			.repeat({
				min : this._minSocialLinks,
				max : this._maxSocialLinks,
				sorting_label_field : this.repeaterId+'.network',
				default : 0
			})
	}

	#layoutGroup() { 
		return new GlobalGroup()
        	.name('layout', 'Display')
			.children([
				Field
					.boolean()
					.name('show_labels', 'Show Labels')
					.id(this.labelsId)
					.set('display','toggle')
					.default(true),
				new Columns()
					.visibleIf(this.labelsId,true)
					.filterChoices(c => (c[0] <= 3))
					.modifyChoices(c => { c.unshift(["0", "Inline"]); return c; })
					.default("0"),
			])
	}

}