const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Columns = require('../Columns');
let Testimonial = require('./Testimonial');
let SwiperJsSettings = require('./SwiperJsSettings');

module.exports = class extends GlobalGroup {

	constructor() { 
		super();
		this.name("testimonials", "Testimonials")
		this.sourceId = randomId()
		this.customItemsId = randomId()
		this._build()
		return this
	}

	_build() {
		this.makeSureOneIsTrue([
			this._showGlobalOption,
			this._showCustomOption
		])
		return this._buildChildrenArray(() => {
			(this._showCustomOption ? this.appendChildren(this.#customOptionField()) : null);
			this.appendChildren(this.#swiperSettingsGroup());
			(this._showGlobalOption ? this.#globalOptionField() : null);
			this.prependChildren(this.#sourceField());
		})
	}

	// --- Show/Hide

	_showGlobalOption = true
	showGlobalOption(val = true) {
		this._showGlobalOption = !!val
		return this._build()
	}

	_showCustomOption = true
	showCustomOption(val = true) {
		this._showCustomOption = !!val
		return this._build()
	}

	// --- Settings

	_applyToTestimonials = false
	applyToTestimonials(fn) { 
		this._applyToTestimonials = typeof fn =='function' ? fn : null
		return this._build()
	}
	
	_makeRepeatable = true
	makeRepeatable(val = true) {
		this._makeRepeatable = !!val
		if (!this._makeRepeatable) {
			this._minTestimonials = 0
			this._maxTestimonials = 1
		}
		return this._build()
	}

	_minTestimonials = 0
	minTestimonials(val) {
		this._minTestimonials = parseInt(val) || 0
		if(this._minTestimonials > 0) {this._makeRepeatable = false}
		return this._build()
	}
	
	_maxTestimonials = 10
	maxTestimonials(val) {
		this._maxTestimonials = parseInt(val) || 10
		if(this._maxTestimonials > 0) {this._makeRepeatable = false}
		return this._build()
	}

	// --- Fields

	#sourceField() {
		let typeOptions = this.getChoiceArrayFromOptions([])
		return Field
			.choice()
			.id(this.sourceId)
			.name('source', 'Testimonial Source')
			.inlineHelpText("Use the global testimonials under 'Global Options' or a custom set.")
			.choices(typeOptions)
	}

	#globalOptionField() {
		this.appendToOptions('global', "Global")
	}

	#customOptionField() {
		let key = "custom"
		this.appendToOptions(key, "Custom Set")	
		let repeaterGroup = this.itemsRepeater((group) => {
			return group.visibleIf(this.sourceId, key)
		})
		return [
			repeaterGroup,
			this.#layoutGroup(repeaterGroup)
		]
	}

	// Keep Public to access directly
	itemsRepeater(applyFn = null) {
		return new Testimonial()
			.name('testimonials', 'Testimonials')
			.id(this.customItemsId)
			.applyIf(typeof applyFn == 'function', field => applyFn(field))
			.applyIf(!!this._applyToTestimonials, field => this._applyToTestimonials(field) )
			.repeat({
				min : this._minTestimonials,
				max : this._maxTestimonials,
				sorting_label_field : this.customItemsId+'.full_name',
				default : 0
			})
	}

	#swiperSettingsGroup(){
		return new SwiperJsSettings()
	}

	#layoutGroup(repeaterGroup = {}) { 
		let { _showImage, _showCompany, _showRole } = repeaterGroup
		return new GlobalGroup()
			.name('layout', 'Layout')
			.visibleIf(this.sourceId, '', 'NOT_EQUAL')
			.appendChildren([
				new Columns()
					.inlineHelpText("Used when Carousel is disabled")
			])
			.appendChildrenIf(_showImage, [
				Field
					.boolean()
					.name('show_image', 'Show Image')
					.inlineHelpText('Shows the image on all people displayed')
					.set('display', 'toggle')
					.default(true)
			])
			.appendChildrenIf(_showCompany,[
				Field
					.boolean()
					.name('show_company', 'Show Company')
					.inlineHelpText('Shows the company on all testimonials')
					.set('display', 'toggle')
					.default(true)
			])
			.appendChildrenIf(_showRole,[
				Field
					.boolean()
					.name('show_title', 'Show Title/Role')
					.inlineHelpText('Shows the title/role on all people displayed')
					.set('display', 'toggle')
					.default(true)
			])	
	}

}