const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Colors = require('../Colors');
let HeadingInherit = require('../HeadingInherit');

module.exports = class extends GlobalGroup {

	constructor() { 
		super()
		this.name('color', 'Theme')
		this.customTextId = randomId()
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#colorField());
			(this._showCustomText ? this.appendChildren(this.#customTextField()) : null);
			(this._showHeadingInherit ? this.appendChildren(this.#headingInheritField()) : null);
		})
	}
	
	// --- Show/Hide

	_showCustomText = true
	showCustomText(val = true) {
		this._showCustomText = !!val
		return this._build()
	}

	_showHeadingInherit = true
	showHeadingInherit(val = true) {
		this._showHeadingInherit = !!val
		return this._build()
	}

	// --- Fields

	#colorField() { 
		return new Colors()
			.name('bg_color', 'Background Color')
	}

	#customTextField() { 
		return [	
			Field
				.boolean()
				.name('custom_text_color', 'Choose custom text color')
				.id(this.customTextId)
				.inlineHelpText('Text color is set automatically. Select this to choose custom text color.')
				.set('display', 'toggle')
				.default(false),
			new Colors()
				.name('text_color', 'Text Color')
				.inlineHelpText('Set the text color for the content.')
				.visibleIf(this.customTextId, true)
		]
	}

	#headingInheritField() {
		return new HeadingInherit()
	}

}