const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Video = require('./Video');

module.exports = class extends GlobalGroup { 
	
	constructor() {
		super()
		this.name('videos', 'Videos')
		this.repeaterId = randomId()
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#videoRepeater());
			(!!this._makeRepeatable ? this.appendChildren(this.#layoutGroup()) : null);
		})
	}

	// --- Settings

	_applyToVideos = false
	applyToVideos(fn) { 
		this._applyToVideos = typeof fn =='function' ? fn : null
		return this._build()
	}
	
	_makeRepeatable = true
	makeRepeatable(val = true) {
		this._makeRepeatable = !!val
		if (!this._makeRepeatable) {
			this._minVideos = 0
			this._maxVideos = 1
		}
		return this._build()
	}

	_minVideos = 0
	minVideos(val) {
		this._minVideos = parseInt(val) || 0
		if(this._minVideos > 0) {this._makeRepeatable = false}
		return this._build()
	}
	
	_maxVideos = 10
	maxVideos(val) {
		this._maxVideos = parseInt(val) || 10
		if(this._maxVideos > 0) {this._makeRepeatable = false}
		return this._build()
	}


	// --- Fields

	#videoRepeater() {
		return new Video()
			.name('videos', (!!this._makeRepeatable ? 'Videos' : 'Video'))
			.id(this.repeaterId)
			.applyIf(!!this._applyToVideos, field => this._applyToVideos(field))
			.prependChildren([
				Field
					.boolean()
					.name('visible', 'Enable this item')
					.set('display', 'toggle')
					.default(true)
			])
			.applyIf(!!this._makeRepeatable, field => { 
				return field
					.repeat({
						min : this._minVideos,
						max : this._maxVideos,
						sorting_label_field : this.repeaterId+'.source',
						default : 0
					})
			})
	}

	#layoutGroup() { 
		return new GlobalGroup()
        	.name('layout', 'Display')
			.appendChildren([
				Field
					.boolean()
					.name('show_arrows', 'Show Navigation Arrows')
					.set('display','toggle')
					.default(true)
			])
	}
}